@@ -7,6 +7,8 @@
 """
 __docformat__ = "restructuredtext en"
 
+import sys
+
 from logilab.common.modutils import LazyObject
 from logilab.mtconverter import guess_mimetype_and_encoding
 from yams import ValidationError
@@ -36,36 +38,24 @@ class VCSException(Exception):
         return ValidationError(self.repoeid, {self.attr: msg})
 
 
-def repository_handler(repoeid):
-    """get repository handler for the repository with the given eid"""
-    return _REPOHDLRS[repoeid]
 
-
-def cache_handler_for_repository(repoent):
-    """register a repository handler"""
+def repository_handler(repoent):
+    """get repository handler for the given repository entity"""
     try:
         repohdlr = _REPOHDLRS[repoent.eid]
         repohdlr.encoding = repoent.encoding # in case it changed
         return repohdlr
     except KeyError:
         pass
-    repohdlr = build_repository_handler(repoent.eid, repoent.type, repoent.path,
-                                        repoent.encoding, repoent._cw._)
-    _REPOHDLRS[repoent.eid] = repohdlr
-    return repohdlr
-
-
-def build_repository_handler(eid, type, path, encoding, _=unicode):
-    """instantiate a repository handler"""
     try:
-        repohdlr = _VCSTYPES[type](eid, path, encoding)
+        repohdlr = _VCSTYPES[repoent.type](repoent.eid, repoent.path, repoent.encoding)
     except KeyError:
-        msg = _('%s is not a known repository type')
-        raise ValidationError(eid, {'type': msg % type})
+        msg = repoent._cw._('%s is not a known repository type')
+        raise ValidationError(repoent.eid, {'type': msg % repoent.type})
     except ImportError:
-        msg = _('missing python bindings to support %s repositories')
-        raise ValidationError(eid, {'type': msg % type})
-    _REPOHDLRS[eid] = repohdlr
+        msg = repoent._cw._('missing python bindings to support %s repositories')
+        raise ValidationError(repoent.eid, {'type': msg % repoent.type})
+    _REPOHDLRS[repoent.eid] = repohdlr
     return repohdlr
 
 
@@ -82,7 +72,7 @@ def import_content(repo, commitevery=10):
             # give a change to threads waiting for a pool
             session.set_pool()
             try:
-                repohdlr = cache_handler_for_repository(repoentity)
+                repohdlr = repository_handler(repoentity)
             except VCSException, ex:
                 repo.error(str(ex))
                 continue
@@ -90,11 +80,12 @@ def import_content(repo, commitevery=10):
                 repohdlr.import_content(repoentity, commitevery)
                 session.commit()
             except:
-                import traceback
-                traceback.print_exc()
+                try:
+                    title = repoentity.dc_title()
+                except:
+                    title = str(repoentity)
                 repoentity.exception(
-                    'error while importing content for vcs repo %s',
-                    repoentity.dc_title())
+                    'error while importing content for vcs repo %s', title)
                 session.rollback()
     finally:
         session.close()
@@ -174,7 +165,7 @@ def import_versioned_file(session, repoeid, date, directory, name):
 
 def import_version_content(session, repoeid, reveid, upath, date, **kwargs):
     """import a new file revision from a repository"""
-    repohdlr = repository_handler(repoeid)
+    repohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
     vfeid = repohdlr.vf_eid(session, upath, date)
     # done in a hook but doing it here as well to avoid an additional query to
     # lookup filename
@@ -196,7 +187,7 @@ def import_version_content(session, repoeid, reveid, upath, date, **kwargs):
 
 def import_deleted_version_content(session, repoeid, reveid, upath, date):
     """import a new deleted file revision from a repository"""
-    repohdlr = repository_handler(repoeid)
+    repohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
     vfeid = repohdlr.vf_eid(session, upath, date)
     args = {'vf': vfeid, 'rev': reveid}
     rql = ('INSERT DeletedVersionContent X: X from_revision REV, X content_for VF '
@@ -210,25 +201,23 @@ from cubicweb.server.sources import storages
 class VCSStorage(storages.Storage):
     """store Bytes attribute value in a version content system"""
 
-    def callback(self, source, value):
-        """sql generator callback when some attribute with a custom storage is
-        accessed
-        """
+    def callback(self, source, session, value):
         repoeid, dir, name, revnum = source.binary_to_str(value).split('\x01')
         repoeid = typed_eid(repoeid)
         revnum = int(revnum)
         try:
-            vcsrepohdlr = repository_handler(repoeid)
+            vcsrepohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
         except Exception, ex:
             source.critical("can't get repository handler for eid %s: %s",
-                            repoeid, ex)
+                            repoeid, ex, exc_info=sys.exc_info())
             return None
         try:
             return Binary(vcsrepohdlr.file_content(dir, name, revnum))
         except Exception, ex:
             source.critical("can't get content for %s/%s at revision %s in vcs "
                             "repository %s: %s",
-                            dir, name, revnum, vcsrepohdlr, ex)
+                            dir, name, revnum, vcsrepohdlr, ex,
+                            exc_info=sys.exc_info())
             return None
 
     def entity_added(self, entity, attr):
