@@ -37,18 +37,21 @@ _MARKER = object()
 class Repository(AnyEntity):
     """customized class for Repository entities"""
     __regid__ ='Repository'
+
+    __permissions__ = ('write',)
     fetch_attrs, fetch_order = fetch_config(['title', 'path', 'subpath', 'type'])
     rest_attr = 'eid' # see #XXX, using path cause pb w/ apache redirection
 
     def dc_title(self):
         if self.title:
             return self.title
-        try:
+        if self.path: # None if user isn't authorized to see path attribute
             title = '%s:%s' % (self.type, self.path)
             if self.subpath:
                 title += ' (%s)' % self.subpath
-        except Unauthorized:
-            title = self._cw._('unauthorized')
+        else:
+            title = self._cw._('%(type)s repository #%(eid)s') % {
+                'type': self.type, 'eid': self.eid}
         return title
 
     def clear_all_caches(self):
@@ -157,8 +160,8 @@ class Repository(AnyEntity):
 class Revision(AnyEntity):
     """customized class for Revision entities"""
     __regid__ ='Revision'
-    fetch_attrs, fetch_order = fetch_config(['revision', 'changeset', 'author',
-                                             'description', 'creation_date'],
+    fetch_attrs, fetch_order = fetch_config(['revision', 'changeset', 'branch',
+                                             'author', 'description', 'creation_date'],
                                             order='DESC')
     __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
@@ -346,7 +349,8 @@ class VersionedFile(AnyEntity):
 class DeletedVersionContent(AnyEntity):
     """customized class for DeletedVersionContent entities"""
     __regid__ ='DeletedVersionContent'
-    fetch_attrs, fetch_order = fetch_config(['from_revision', 'content_for'], order='DESC')
+    fetch_attrs, fetch_order = fetch_config(['from_revision', 'content_for'],
+                                            order='DESC')
     __implements__ = AnyEntity.__implements__ + (IPrevNext,)
 
     def dc_title(self):
@@ -457,14 +461,16 @@ class DeletedVersionContent(AnyEntity):
             vf = session.execute('Any X,D,N,R WHERE X name N, X directory D,'
                                  'X from_repository R, X eid %(x)s',
                                  {'x': vfeid}).get_entity(0, 0)
-            vcsrepoeid = vf.repository.eid
+            vcsrepo = vf.repository
+        else:
+            vcsrepo = self._cw.entity_from_eid(vcsrepoeid)
         try:
-            transaction = session.transaction_data['vctransactions'][vcsrepoeid]
+            transaction = session.transaction_data['vctransactions'][vcsrepo.eid]
         except KeyError:
             raise QueryError('you must create a Revision instance before '
                              'adding some content')
         CheckRevisionOp(session, entity=self)
-        return bridge.repository_handler(vcsrepoeid), transaction
+        return bridge.repository_handler(vcsrepo), transaction
 
 
 from cubicweb import QueryError
