@@ -1,7 +1,7 @@
 """repository abstraction for supported repositories
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -67,7 +67,7 @@ class VCSRepository(object):
             return self.vf_path_cache[path]
         except KeyError:
             directory, fname = split(path)
-            rset = session.unsafe_execute(
+            rset = session.execute(
                 'Any X WHERE X directory %(dir)s, X name %(name)s, '
                 'X from_repository R, R eid %(r)s',
                 {'dir': directory, 'name': fname, 'r': self.eid})
