@@ -39,7 +39,7 @@ class HGRepository(repo.VCSRepository):
         try:
             repo = self.hgrepo()
         except Exception, ex:
-            self.error('Impossible to open repository %s (%s)', self, ex)
+            self.exception('Impossible to open repository %s (%s)', self, ex)
             return
         # actual rev is the *number* of revision, latest rev the highest
         # revision number while hg revisions start at 0 -> - 1
@@ -50,8 +50,8 @@ class HGRepository(repo.VCSRepository):
             # striped repo
             # very minimal support, this won't work if local number of
             # revisions has changed due to the strip
-            self.warning('strip detected ? latest known revision is %s, latest '
-                         'repository revision is %s', latestrev, actualrev)
+            self.warning('%s: strip detected ? latest known revision is %s, latest '
+                         'repository revision is %s', repoentity.path, latestrev, actualrev)
             session.execute('DELETE Revision X WHERE X revision > %(rev)s',
                             {'rev': actualrev})
             return
@@ -63,7 +63,7 @@ class HGRepository(repo.VCSRepository):
                 self.import_revision(repoentity, repo, i)
             except:
                 self.critical('error while importing revision %s of %s',
-                              i, repoentity.path)
+                              i, repoentity.path, exc_info=True)
                 raise
             if not i % commitevery:
                 # give a change to threads waiting for a pool by freeing it then
