@@ -81,7 +81,7 @@ class SVNRepository(repo.VCSRepository):
                 editor.import_revision()
             except:
                 self.critical('error while importing revision %s of %s',
-                              rev, repoentity.path)
+                              rev, repoentity.path, exc_info=True)
                 raise
             if not rev % commitevery:
                 # give a change to threads waiting for a pool by freeing it then
