@@ -5,14 +5,24 @@ try:
 except ImportError: # no server installation
     pass
 else:
-
     options = (
+        ('repository-import',
+         {'type' : 'yn',
+          'default': True,
+          'help': 'Is the repository responsible to automatically import new '
+                   'revisions from repositories? '
+                   'You should say yes unless you don\'t want this behaviour '
+                   'or if you use a multiple repositories setup, in which '
+                   'case you should say yes on one repository, no on others.',
+          'level': 2,
+          'group': 'vcsfile',
+          }),
         ('check-revision-interval',
          {'type' : 'int',
           'default': 5*60,
           'help': 'interval between checking of new revisions in repositories \
 (default to 5 minutes).',
-          'inputlevel': 2,
+          'level': 2,
           'group': 'vcsfile',
           }),
         ('check-revision-commmit-every',
@@ -20,7 +30,7 @@ else:
           'default': 1,
           'help': 'after how much new imported revisions the transaction \
 should be commited (default to 1, e.g. on each revision).',
-          'inputlevel': 2,
+          'level': 2,
           'group': 'vcsfile',
           }),
         ('import-revision-content',
@@ -28,7 +38,7 @@ should be commited (default to 1, e.g. on each revision).',
           'default': True,
           'help': 'Import content of file touched by a revision. This may \
 cause performance issue when scaling.',
-          'inputlevel': 2,
+          'level': 2,
           'group': 'vcsfile',
           }),
         )
