@@ -4,7 +4,7 @@ from os import system, unlink, chdir, getcwd
 from os.path import join, split, exists, abspath
 import tempfile
 
-from cubicweb import Binary, QueryError, ValidationError
+from cubicweb import Binary, QueryError, ValidationError, Unauthorized
 
 from cubes.vcsfile import entities, bridge
 
@@ -22,6 +22,7 @@ class _WriteTC(VCSFileTC):
         except:
             rmtree(str(self.repo_path))
             raise
+        self.grant_write_perm('managers')
 
     def tearDown(self):
         VCSFileTC.tearDown(self)
@@ -55,6 +56,11 @@ class _WriteTC(VCSFileTC):
         bridge.import_content(self.repo)
         self.assertEquals(len(self.execute('Any X WHERE X revision %(r)s', {'r': rev.revision})), 1)
 
+    def test_new_revision_security(self):
+        self.execute('DELETE CWPermission X')
+        self.commit()
+        self.assertRaises(Unauthorized, self._new_toto_revision)
+
 # XXX unable to do this, we need to get the associated VersionedFile in source.add_entity...
 #     def test_two_steps_new_revision(self):
 #         vf = self.execute('VersionedFile X WHERE X name "toto.txt"')
