@@ -43,3 +43,13 @@ class VCSFileTC(CubicWebTC):
         t = clock()
         bridge.import_content(self.repo, commitevery=3)
         #print 'import content time %.3f' % (clock() - t)
+
+    def grant_write_perm(self, group):
+        req = self.request()
+        managers = req.execute('CWGroup G WHERE G name %(group)s',
+                               {'group': group}).get_entity(0, 0)
+        req.create_entity(
+            'CWPermission', name=u"write", label=u'repo x write perm',
+            reverse_require_permission=self.vcsrepo,
+            require_group=managers)
+        self.commit()
