@@ -105,7 +105,7 @@ class VFHEADRevisionAction(VFAction):
     order = 109
 
     def url(self):
-        vfile = self.cw_rset.get_entity(self.row or 0, self.col or 0)
+        vfile = self.cw_rset.get_entity(self.cw_row or 0, self.cw_col or 0)
         return self._cw.build_url(rql='Any V WHERE V content_for X, '
                               'V from_revision R, R revision %s, X eid %s'
                               % (vfile.head.revision, vfile.eid))
@@ -125,12 +125,12 @@ class VFAddRevisionAction(VFAction):
     order = 111
 
     def url(self):
-        vfile = self.cw_rset.get_entity(self.row or 0, self.col or 0)
+        vfile = self.cw_rset.get_entity(self.cw_row or 0, self.cw_col or 0)
         linkto = 'from_repository:%s:subject' % vfile.repository.eid
         return self._cw.build_url('add/Revision', vfeid=vfile.eid,
                               __linkto=linkto,
                               __redirectpath=vfile.rest_path(),
-                              __redirectvid=self.req.form.get('__redirectvid', ''))
+                              __redirectvid=self._cw.form.get('__redirectvid', ''))
 
 
 class VFPutUpdateAction(VFAction):
