@@ -17,15 +17,41 @@ from cubicweb.web import uicfg
 from cubicweb.web.views import (ibreadcrumbs, idownloadable,
                                 baseviews, primary, tabs)
 
+from cubicweb.web import uicfg
+
+# primary view tweaks
 _pvs = uicfg.primaryview_section
-_pvs.tag_attribute(('VersionedFile', 'name'), 'hidden')
-_pvs.tag_attribute(('VersionedFile', 'directory'), 'hidden')
-_pvs.tag_object_of(('*', 'from_repository', '*'), 'hidden')
+_pvdc = uicfg.primaryview_display_ctrl
+_abaa = uicfg.actionbox_appearsin_addmenu
+
+# internal purpose relation
+_pvs.tag_subject_of(('*', 'at_revision', '*'), 'hidden')
+_pvs.tag_object_of(('*', 'at_revision', '*'), 'hidden')
+
+_pvs.tag_attribute(('VersionedFile', 'name'), 'hidden') # in title
+_pvs.tag_attribute(('VersionedFile', 'directory'), 'hidden') # in title
+_pvs.tag_subject_of(('VersionedFile', 'from_repository', '*'), 'hidden') # in breadcrumb
+_pvs.tag_object_of(('*', 'content_for', 'VersionedFile'), 'hidden') # in render_entity_relations
+
+_pvs.tag_subject_of(('Revision', 'parent_revision', 'Revision'), 'attributes')
+_pvs.tag_object_of(('Revision', 'parent_revision', 'Revision'), 'attributes')
+_pvs.tag_subject_of(('Revision', 'from_repository', '*'), 'hidden') # in breadcrumb
+_pvs.tag_object_of(('*', 'from_revision', '*'), 'hidden')
+
 for etype in ('DeletedVersionContent', 'VersionContent'):
     _pvs.tag_attribute((etype, 'revision'), 'hidden')
     _pvs.tag_attribute((etype, 'author'), 'hidden')
     _pvs.tag_subject_of((etype, 'content_for', '*'), 'hidden')
 
+_pvdc.tag_subject_of(('*', 'from_revision', '*'), {'vid': 'incontext'})
+_pvdc.tag_subject_of(('*', 'from_repository', '*'), {'vid': 'incontext'})
+_pvdc.tag_subject_of(('*', 'content_for', '*'), {'vid': 'incontext'})
+
+# we don't want automatic addrelated action for the following relations...
+for rtype in ('from_repository', 'from_revision', 'content_for',
+              'parent_revision'):
+    _abaa.tag_object_of(('*', rtype, '*'), False)
+
 
 def render_entity_summary(self, entity):
     if entity.description:
@@ -71,9 +97,15 @@ class RepositoryFilesTab(EntityView):
     __select__ = implements('Repository')
 
     def cell_call(self, row, col):
-        entity = self.rset.get_entity(row, col)
-        filesrql = entity.related_rql('from_repository', 'object', ('VersionedFile',))
-        self.wview('list', self._cw.execute(filesrql, {'x': entity.eid}), 'noresult')
+        entity = self.cw_rset.get_entity(row, col)
+        rset = self._cw.execute(
+            'Any VF,VFMD, VFD,VFN ORDERBY VFD,VFN WHERE '
+            'VF modification_date VFMD, VF directory VFD, VF name VFN,'
+            'VF from_repository X, X eid %(x)s',
+            {'x': entity.eid})
+        self.wview('table', rset, 'noresult',
+                   paginate=True, displayfilter=True,
+                   displaycols=[0, 1], cellvids={0: 'incontext'})
 
 
 class RepositoryHistoryTab(EntityView):
@@ -81,9 +113,14 @@ class RepositoryHistoryTab(EntityView):
     __select__ = implements('Repository')
 
     def cell_call(self, row, col):
-        entity = self.rset.get_entity(row, col)
-        revisionsrql = entity.related_rql('from_repository', 'object', ('Revision',))
-        self.wview('table', self._cw.execute(revisionsrql, {'x': entity.eid}), 'noresult')
+        entity = self.cw_rset.get_entity(row, col)
+        rset = self._cw.execute(
+            'Any R,RB,RA,RD,RCD, RN,RCS ORDERBY RN DESC WHERE '
+            'R branch RB, R author RA, R description RD, R creation_date RCD,'
+            'R revision RN, R changeset RCS, R from_repository X, X eid %(x)s',
+            {'x': entity.eid})
+        self.wview('table', rset, 'noresult',
+                   paginate=True, displayfilter=True, displaycols=range(5))
 
 
 class DVCPrimaryView(primary.PrimaryView):
@@ -128,6 +165,28 @@ class VCMetaDataView(baseviews.MetaDataView):
             self.w(tags.span(entity.author, klass='value'))
         self.w(u'</div>')
 
+class VCRevisionView(EntityView):
+    __regid__ = 'revision'
+    __select__ = implements('VersionContent', 'DeletedVersionContent')
+
+    def cell_call(self, row, col):
+        vc = self.cw_rset.get_entity(row, col)
+        self.w(u'<a href="%s">' % vc.absolute_url())
+        vc.rev.view('shorttext', w=self.w)
+        self.w(u'</a>')
+
+class RevisionShortView(EntityView):
+    __regid__ = 'shorttext'
+    __select__ = implements('Revision')
+    content_type = 'text/plain'
+
+    def cell_call(self, row, col):
+        rev = self.cw_rset.get_entity(row, col)
+        if rev.changeset:
+            self.w(u'#%s:%s' % (rev.revision, rev.changeset))
+        else:
+            self.w(u'#%s' % rev.revision)
+
 
 class VFPrimaryView(primary.PrimaryView):
     __select__ = implements('VersionedFile')
@@ -140,8 +199,9 @@ class VFPrimaryView(primary.PrimaryView):
         else:
             head = entity.head
             contenttype = head.download_content_type()
+            self.field('head', head.rev.view('incontext'))
             if contenttype.startswith('image/'):
-                self.wview('image', head.rset, row=head.row)
+                self.wview('image', head.cw_rset, row=head.cw_row)
             else:
                 try:
                     if ENGINE.has_input(contenttype):
@@ -154,40 +214,29 @@ class VFPrimaryView(primary.PrimaryView):
         self.w(u'</div>')
 
     def render_entity_relations(self, entity):
-        revisions = entity.revisions
-        self.w(u'<table class="listing">\n')
-        self.w(u'<tr><th>%s</th><th>%s</th><th>%s</th><th>&nbsp;</th></tr>\n' %
-               (_('revision'), _('author'), _('comment')))
-        for vc in reversed(revisions):
-            self.w(u'<tr><td><a href="%s">%s</a></td><td>%s</td><td>%s</td></tr>\n'
-                   % (xml_escape(vc.absolute_url()), vc.revision,
-                      xml_escape(vc.author or u''),
-                      xml_escape(vc.description or u'')))
-        self.w(u'</table>\n')
+        super(VFPrimaryView, self).render_entity_relations(entity)
+        self.w(u'<h3>%s</h3>' % self._cw._('Revisions for this file'))
+        rset = self._cw.execute(
+            'Any VC,RB,RA,RD,RC, R ORDERBY R DESC WHERE '
+            'VC content_for VF, VC from_revision R, '
+            'R branch RB, R author RA, R description RD, R creation_date RC,'
+            'VF eid %(x)s',
+            {'x': entity.eid})
+        self.wview('table', rset, 'noresult',
+                   paginate=True, displayfilter=True,
+                   displaycols=range(5),
+                   cellvids={0: 'revision'})
 
 
 class RevisionPrimaryView(primary.PrimaryView):
     __select__ = implements('Revision')
 
-    def render_entity_attributes(self, rev):
-        self.field('description', xml_escape(rev.description))
-        self.field('author', xml_escape(rev.author))
-        if rev.branch:
-            self.field('branch', xml_escape(rev.branch))
-        self.field('from_repository', rev.repository.dc_title())
-        parents = rev.related('parent_revision')
-        if parents:
-            self.field('parent_revision', self._cw.view('csv', parents))
-        children = rev.related('parent_revision', 'object')
-        if children:
-            self.field('parent_revision_object', self._cw.view('csv', children))
-
     def render_entity_relations(self, rev):
         versioned = rev.reverse_from_revision
         if versioned:
             self.w(u'<table class="listing">')
             self.w(u'<tr><th>%s</th></tr>' %
-                   self._cw._('objects concerned by this revision'))
+                   self._cw._('files modified by this revision'))
             for obj in versioned:
                 self.w(u'<tr><td><a href="%s">%s</a></td></tr>' % (
                     obj.absolute_url(), xml_escape(obj.dc_title())))
@@ -202,5 +251,5 @@ class DVCBreadCrumbView(ibreadcrumbs.BreadCrumbView):
     __select__ = implements('VersionContent', 'DeletedVersionContent')
 
     def cell_call(self, row, col):
-        entity = self.rset.get_entity(row, col)
+        entity = self.cw_rset.get_entity(row, col)
         self.w(entity.rev.dc_title())
